@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 from __future__ import absolute_import
@@ -18,7 +18,7 @@ missing = Sentinel("Missing")
 
 class QueryClient(object):
     """
-    API for APM Trace service. Use this API to query the Traces and associated Spans.
+    Use the Application Performance Monitoring Trace Explorer API to query traces and associated spans in Trace Explorer. For more information, see [Application Performance Monitoring](https://docs.oracle.com/iaas/application-performance-monitoring/index.html).
     """
 
     def __init__(self, config, **kwargs):
@@ -59,11 +59,15 @@ class QueryClient(object):
 
         :param obj circuit_breaker_strategy: (optional)
             A circuit breaker strategy to apply to all calls made by this service client (i.e. at the client level).
-            This client will not have circuit breakers enabled by default, users can use their own circuit breaker strategy or the convenient :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` provided by the SDK to enable it.
+            This client uses :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` as default if no circuit breaker strategy is provided.
             The specifics of circuit breaker strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/circuit_breakers.html>`__.
 
         :param function circuit_breaker_callback: (optional)
             Callback function to receive any exceptions triggerred by the circuit breaker.
+
+        :param allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this client should allow control characters in the response object. By default, the client will not
+            allow control characters to be in the response object.
         """
         validate_config(config, signer=kwargs.get('signer'))
         if 'signer' in kwargs:
@@ -92,18 +96,22 @@ class QueryClient(object):
         }
         if 'timeout' in kwargs:
             base_client_init_kwargs['timeout'] = kwargs.get('timeout')
+        if base_client_init_kwargs.get('circuit_breaker_strategy') is None:
+            base_client_init_kwargs['circuit_breaker_strategy'] = circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY
+        if 'allow_control_chars' in kwargs:
+            base_client_init_kwargs['allow_control_chars'] = kwargs.get('allow_control_chars')
         self.base_client = BaseClient("query", config, signer, apm_traces_type_mapping, **base_client_init_kwargs)
         self.retry_strategy = kwargs.get('retry_strategy')
         self.circuit_breaker_callback = kwargs.get('circuit_breaker_callback')
 
     def list_quick_picks(self, apm_domain_id, **kwargs):
         """
-        Returns a list of predefined quick pick queries intended to assist the user
+        Returns a list of predefined Quick Pick queries intended to assist the user
         to choose a query to run.  There is no sorting applied on the results.
 
 
         :param str apm_domain_id: (required)
-            The APM Domain Id the request is intended for.
+            The APM Domain ID the request is intended for.
 
         :param str opc_request_id: (optional)
             Unique Oracle-assigned identifier for the request.  If you need to contact Oracle about a
@@ -124,17 +132,24 @@ class QueryClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type list of :class:`~oci.apm_traces.models.QuickPickSummary`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/apmtraces/list_quick_picks.py.html>`__ to see an example of how to use list_quick_picks API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/apmtraces/list_quick_picks.py.html>`__ to see an example of how to use list_quick_picks API.
         """
         resource_path = "/queries/quickPicks"
         method = "GET"
+        operation_name = "list_quick_picks"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/apm-trace-explorer/20200630/QuickPickSummary/ListQuickPicks"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_request_id",
             "limit",
@@ -174,34 +189,41 @@ class QueryClient(object):
                 method=method,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="list[QuickPickSummary]")
+                response_type="list[QuickPickSummary]",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="list[QuickPickSummary]")
+                response_type="list[QuickPickSummary]",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def query(self, apm_domain_id, time_span_started_greater_than_or_equal_to, time_span_started_less_than, query_details, **kwargs):
         """
-        Given a query, constructed according to the APM Defined Query Syntax, retrieves the results - selected attributes,
-        and aggregations of the queried entity.  Query Results are filtered by the filter criteria specified in the where clause.
+        Retrieves the results (selected attributes and aggregations) of a query constructed according to the Application Performance Monitoring Defined Query Syntax.
+        Query results are filtered by the filter criteria specified in the where clause.
         Further query results are grouped by the attributes specified in the group by clause.  Finally,
         ordering (asc/desc) is done by the specified attributes in the order by clause.
 
 
         :param str apm_domain_id: (required)
-            The APM Domain Id the request is intended for.
+            The APM Domain ID the request is intended for.
 
         :param datetime time_span_started_greater_than_or_equal_to: (required)
-            Include spans that have a `spanStartTime` equal to or greater this value.
+            Include spans that have a `spanStartTime` equal to or greater than this value.
 
         :param datetime time_span_started_less_than: (required)
             Include spans that have a `spanStartTime`less than this value.
 
         :param oci.apm_traces.models.QueryDetails query_details: (required)
-            Request body containing the query to be run against our repository.
+            Request body containing the query to be run against the trace data and to filter and
+            retrieve trace data results.
 
         :param str opc_request_id: (optional)
             Unique Oracle-assigned identifier for the request.  If you need to contact Oracle about a
@@ -222,17 +244,24 @@ class QueryClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.apm_traces.models.QueryResultResponse`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/apmtraces/query.py.html>`__ to see an example of how to use query API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/apmtraces/query.py.html>`__ to see an example of how to use query API.
         """
         resource_path = "/queries/actions/runQuery"
         method = "POST"
+        operation_name = "query"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/apm-trace-explorer/20200630/QueryResultResponse/Query"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_request_id",
             "limit",
@@ -275,7 +304,10 @@ class QueryClient(object):
                 query_params=query_params,
                 header_params=header_params,
                 body=query_details,
-                response_type="QueryResultResponse")
+                response_type="QueryResultResponse",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -283,108 +315,7 @@ class QueryClient(object):
                 query_params=query_params,
                 header_params=header_params,
                 body=query_details,
-                response_type="QueryResultResponse")
-
-    def query_old(self, apm_domain_id, time_span_started_greater_than_or_equal_to, time_span_started_less_than, query_details, **kwargs):
-        """
-        THIS API ENDPOINT WILL BE DEPRECATED AND INSTEAD /queries/actions/runQuery as defined below WILL BE USED GOING FORWARD.  THIS EXISTS JUST
-        AS A TEMPORARY PLACEHOLDER SO AS TO BE BACKWARDS COMPATIBLE WITH THE UI BETWEEN RELEASE CYCLES.
-        Given a query, constructed according to the APM Defined Query Syntax, retrieves the results - selected attributes,
-        and aggregations of the queried entity.  Query Results are filtered by the filter criteria specified in the where clause.
-        Further query results are grouped by the attributes specified in the group by clause.  Finally,
-        ordering (asc/desc) is done by the specified attributes in the order by clause.
-
-
-        :param str apm_domain_id: (required)
-            The APM Domain Id the request is intended for.
-
-        :param datetime time_span_started_greater_than_or_equal_to: (required)
-            Include spans that have a `spanStartTime` equal to or greater this value.
-
-        :param datetime time_span_started_less_than: (required)
-            Include spans that have a `spanStartTime`less than this value.
-
-        :param oci.apm_traces.models.QueryDetails query_details: (required)
-            Request body containing the query to be run against our repository.
-
-        :param str opc_request_id: (optional)
-            Unique Oracle-assigned identifier for the request.  If you need to contact Oracle about a
-            particular request, please provide the request ID.
-
-        :param int limit: (optional)
-            The maximum number of items to return.
-
-        :param str page: (optional)
-            The page token representing the page at which to start retrieving results.
-            This is usually retrieved from a previous response.
-
-        :param obj retry_strategy: (optional)
-            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.
-
-            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
-            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.
-
-            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
-
-        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.apm_traces.models.QueryResultResponse`
-        :rtype: :class:`~oci.response.Response`
-
-        :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/apmtraces/query_old.py.html>`__ to see an example of how to use query_old API.
-        """
-        resource_path = "/queries/action/runQuery"
-        method = "POST"
-
-        # Don't accept unknown kwargs
-        expected_kwargs = [
-            "retry_strategy",
-            "opc_request_id",
-            "limit",
-            "page"
-        ]
-        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
-        if extra_kwargs:
-            raise ValueError(
-                "query_old got unknown kwargs: {!r}".format(extra_kwargs))
-
-        query_params = {
-            "apmDomainId": apm_domain_id,
-            "limit": kwargs.get("limit", missing),
-            "page": kwargs.get("page", missing),
-            "timeSpanStartedGreaterThanOrEqualTo": time_span_started_greater_than_or_equal_to,
-            "timeSpanStartedLessThan": time_span_started_less_than
-        }
-        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}
-
-        header_params = {
-            "accept": "application/json",
-            "content-type": "application/json",
-            "opc-request-id": kwargs.get("opc_request_id", missing)
-        }
-        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}
-
-        retry_strategy = self.base_client.get_preferred_retry_strategy(
-            operation_retry_strategy=kwargs.get('retry_strategy'),
-            client_retry_strategy=self.retry_strategy
-        )
-
-        if retry_strategy:
-            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
-                self.base_client.add_opc_client_retries_header(header_params)
-                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
-            return retry_strategy.make_retrying_call(
-                self.base_client.call_api,
-                resource_path=resource_path,
-                method=method,
-                query_params=query_params,
-                header_params=header_params,
-                body=query_details,
-                response_type="QueryResultResponse")
-        else:
-            return self.base_client.call_api(
-                resource_path=resource_path,
-                method=method,
-                query_params=query_params,
-                header_params=header_params,
-                body=query_details,
-                response_type="QueryResultResponse")
+                response_type="QueryResultResponse",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
