@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 from __future__ import absolute_import
@@ -40,8 +40,9 @@ APPEND_USER_AGENT_ENV_VAR_NAME = "OCI_SDK_APPEND_USER_AGENT"
 APPEND_USER_AGENT = os.environ.get(APPEND_USER_AGENT_ENV_VAR_NAME)
 USER_INFO = "Oracle-PythonSDK/{}".format(__version__)
 
-DICT_VALUE_TYPE_REGEX = re.compile('dict\(str, (.+?)\)$')  # noqa: W605
-LIST_ITEM_TYPE_REGEX = re.compile('list\[(.+?)\]$')  # noqa: W605
+DICT_VALUE_TYPE_REGEX = re.compile(r'dict\(str, (.+?)\)$')  # noqa: W605
+LIST_ITEM_TYPE_REGEX = re.compile(r'list\[(.+?)\]$')  # noqa: W605
+TROUBLESHOOT_URL = 'https://docs.oracle.com/en-us/iaas/Content/API/Concepts/sdk_troubleshooting.htm'
 
 # Expect header is enabled by default
 enable_expect_header = True
@@ -259,6 +260,8 @@ class BaseClient(object):
         "object": object
     }
 
+    ALLOW_CONTROL_CHARACTERS = False
+
     def __init__(self, service, config, signer, type_mapping, **kwargs):
         validate_config(config, signer=signer)
         self.signer = signer
@@ -271,6 +274,10 @@ class BaseClient(object):
         self._endpoint = None
         self._base_path = kwargs.get('base_path')
         self.service_endpoint_template = kwargs.get('service_endpoint_template')
+        self.endpoint_service_name = kwargs.get('endpoint_service_name')
+
+        # By default self._allow_control_chars will be None. The user would need to explicitly set it to True or False
+        self._allow_control_chars = kwargs.get('allow_control_chars')
 
         if self.regional_client:
             if kwargs.get('service_endpoint'):
@@ -286,7 +293,8 @@ class BaseClient(object):
                     service,
                     service_endpoint_template=self.service_endpoint_template,
                     region=region_to_use,
-                    endpoint=config.get('endpoint'))
+                    endpoint=config.get('endpoint'),
+                    endpoint_service_name=self.endpoint_service_name)
         else:
             if not kwargs.get('service_endpoint'):
                 raise exceptions.MissingEndpointForNonRegionalServiceClientError('An endpoint must be provided for a non-regional service client')
@@ -336,6 +344,7 @@ class BaseClient(object):
                 )
             # Equivalent to decorating the request function with Circuit Breaker
             self.request = circuit_breaker(self.request)
+        self.logger.debug('Endpoint: {}'.format(self._endpoint))
 
     @property
     def endpoint(self):
@@ -358,17 +367,28 @@ class BaseClient(object):
 
     def set_region(self, region):
         if self.regional_client:
-            self.endpoint = regions.endpoint_for(self.service, service_endpoint_template=self.service_endpoint_template, region=region)
+            self.endpoint = regions.endpoint_for(self.service, service_endpoint_template=self.service_endpoint_template, region=region, endpoint_service_name=self.endpoint_service_name)
         else:
             raise TypeError('Setting the region is not allowed for non-regional service clients. You must instead set the endpoint')
 
+    @property
+    def allow_control_chars(self):
+        return self._allow_control_chars
+
+    @allow_control_chars.setter
+    def allow_control_chars(self, bool):
+        self._allow_control_chars = bool
+
     def call_api(self, resource_path, method,
                  path_params=None,
                  query_params=None,
                  header_params=None,
                  body=None,
                  response_type=None,
-                 enforce_content_headers=True):
+                 enforce_content_headers=True,
+                 allow_control_chars=None,
+                 operation_name=None,
+                 api_reference_link=None):
         """
         Makes the HTTP request and return the deserialized data.
 
@@ -381,6 +401,9 @@ class BaseClient(object):
         :param response_type: (optional) Response data type.
         :param enforce_content_headers: (optional) Whether content headers should be added for
             PUT and POST requests when not present.  Defaults to True.
+        :param allow_control_chars: (optional) Boolean that allows whether or not the response object can contain control chars
+        :param operation_name: (optional) String that represents the operational name of the API call.
+        :param api_reference_link: (optional) String that represents the link to the API reference page for this operation.
         :return: A Response object, or throw in the case of an error.
 
         """
@@ -442,7 +465,7 @@ class BaseClient(object):
             call_attempts = 0
             while call_attempts < 2:
                 try:
-                    return self.request(request)
+                    return self.request(request, allow_control_chars, operation_name, api_reference_link)
                 except exceptions.ServiceError as e:
                     call_attempts += 1
                     if e.status == 401 and call_attempts < 2:
@@ -451,7 +474,7 @@ class BaseClient(object):
                         raise
         else:
             start = timer()
-            response = self.request(request)
+            response = self.request(request, allow_control_chars, operation_name, api_reference_link)
             end = timer()
             self.logger.debug('time elapsed for request: {}'.format(str(end - start)))
             return response
@@ -530,7 +553,7 @@ class BaseClient(object):
 
         return processed_query_params
 
-    def request(self, request):
+    def request(self, request, allow_control_chars=None, operation_name=None, api_reference_link=None):
         self.logger.info(utc_now() + "Request: %s %s" % (str(request.method), request.url))
 
         initial_circuit_breaker_state = None
@@ -564,8 +587,14 @@ class BaseClient(object):
             if response and hasattr(response, 'elapsed'):
                 self.logger.debug(utc_now() + "time elapsed in response: " + str(response.elapsed))
         except requests.exceptions.ConnectTimeout as e:
+            if not e.args:
+                e.args = ('',)
+            e.args = e.args + ("Request Endpoint: " + request.method + " " + request.url + " See {} for help troubleshooting this error, or contact support and provide this full error message.".format(TROUBLESHOOT_URL),)
             raise exceptions.ConnectTimeout(e)
         except requests.exceptions.RequestException as e:
+            if not e.args:
+                e.args = ('',)
+            e.args = e.args + ("Request Endpoint: " + request.method + " " + request.url + " See {} for help troubleshooting this error, or contact support and provide this full error message.".format(TROUBLESHOOT_URL),)
             raise exceptions.RequestException(e)
 
         response_type = request.response_type
@@ -573,14 +602,18 @@ class BaseClient(object):
 
         # Raise Service Error or Transient Service Error
         if not 200 <= response.status_code <= 299:
-            service_code, message = self.get_deserialized_service_code_and_message(response)
+            target_service = self.service
+            request_endpoint = request.method + " " + request.url
+            client_version = USER_INFO
+            timestamp = datetime.now().isoformat()
+            service_code, message = self.get_deserialized_service_code_and_message(response, allow_control_chars)
             if isinstance(self.circuit_breaker_strategy, CircuitBreakerStrategy) and self.circuit_breaker_strategy.is_transient_error(response.status_code, service_code):
                 new_circuit_breaker_state = CircuitBreakerMonitor.get(self.circuit_breaker_name).state
                 if initial_circuit_breaker_state != new_circuit_breaker_state:
                     self.logger.warning("Circuit Breaker state changed from {} to {}".format(initial_circuit_breaker_state, new_circuit_breaker_state))
-                self.raise_transient_service_error(request, response, service_code, message)
+                self.raise_transient_service_error(request, response, service_code, message, operation_name, api_reference_link, target_service, request_endpoint, client_version, timestamp)
             else:
-                self.raise_service_error(request, response, service_code, message)
+                self.raise_service_error(request, response, service_code, message, operation_name, api_reference_link, target_service, request_endpoint, client_version, timestamp)
 
         if stream:
             # Don't unpack a streaming response body
@@ -589,7 +622,7 @@ class BaseClient(object):
             # Don't deserialize data responses.
             deserialized_data = response.content
         elif response_type:
-            deserialized_data = self.deserialize_response_data(response.content, response_type)
+            deserialized_data = self.deserialize_response_data(response.content, response_type, allow_control_chars)
         else:
             deserialized_data = None
 
@@ -736,24 +769,36 @@ class BaseClient(object):
 
         return result
 
-    def raise_service_error(self, request, response, service_code, message):
+    def raise_service_error(self, request, response, service_code, message, operation_name=None, api_reference_link=None, target_service=None, request_endpoint=None, client_version=None, timestamp=None):
         raise exceptions.ServiceError(
             response.status_code,
             service_code,
             response.headers,
             message,
-            original_request=request)
+            original_request=request,
+            operation_name=operation_name,
+            api_reference_link=api_reference_link,
+            target_service=target_service,
+            request_endpoint=request_endpoint,
+            client_version=client_version,
+            timestamp=timestamp)
 
-    def raise_transient_service_error(self, request, response, service_code, message):
+    def raise_transient_service_error(self, request, response, service_code, message, operation_name=None, api_reference_link=None, target_service=None, request_endpoint=None, client_version=None, timestamp=None):
         raise exceptions.TransientServiceError(
             response.status_code,
             service_code,
             response.headers,
             message,
-            original_request=request)
+            original_request=request,
+            operation_name=operation_name,
+            api_reference_link=api_reference_link,
+            target_service=target_service,
+            request_endpoint=request_endpoint,
+            client_version=client_version,
+            timestamp=timestamp)
 
-    def get_deserialized_service_code_and_message(self, response):
-        deserialized_data = self.deserialize_response_data(response.content, 'object')
+    def get_deserialized_service_code_and_message(self, response, allow_control_chars=None):
+        deserialized_data = self.deserialize_response_data(response.content, 'object', allow_control_chars)
         service_code = None
         message = None
 
@@ -768,13 +813,14 @@ class BaseClient(object):
 
         return service_code, message
 
-    def deserialize_response_data(self, response_data, response_type):
+    def deserialize_response_data(self, response_data, response_type, allow_control_chars=None):
         """
         Deserializes response into an object.
 
         :param response_data: object to be deserialized.
         :param response_type: class literal for
             deserialized object, or string of class name.
+        :param allow_control_chars: boolean to allow control character in a response. Defaults to None
 
         :return: deserialized object.
         """
@@ -782,7 +828,10 @@ class BaseClient(object):
         response_data = response_data.decode('utf8')
 
         try:
-            json_response = json.loads(response_data)
+            should_allow_control_chars = self.should_allow_control_chars(allow_control_chars)
+
+            # Taking the inverse result because strict=True means we do not allow control characters.
+            json_response = json.loads(response_data, strict=not should_allow_control_chars)
             # Load everything as JSON and then verify that the object returned
             # is a string (six.text_type) if the response type is a string.
             # This is matches the previous behavior, which happens to strip
@@ -819,12 +868,12 @@ class BaseClient(object):
             return None
 
         if cls.startswith('list['):
-            sub_kls = re.match('list\[(.*)\]', cls).group(1)  # noqa: W605
+            sub_kls = re.match(r'list\[(.*)\]', cls).group(1)  # noqa: W605
             return [self.__deserialize(sub_data, sub_kls)
                     for sub_data in data]
 
         if cls.startswith('dict('):
-            sub_kls = re.match('dict\(([^,]*), (.*)\)', cls).group(2)  # noqa: W605
+            sub_kls = re.match(r'dict\(([^,]*), (.*)\)', cls).group(2)  # noqa: W605
             return {k: self.__deserialize(v, sub_kls)
                     for k, v in data.items()}
 
@@ -941,3 +990,22 @@ class BaseClient(object):
         elif retry.GLOBAL_RETRY_STRATEGY:
             retry_strategy = retry.GLOBAL_RETRY_STRATEGY
         return retry_strategy
+
+    def should_allow_control_chars(self, allow_control_chars):
+        request_configuration = allow_control_chars
+        client_configuration = self._allow_control_chars
+        global_configuration = BaseClient.ALLOW_CONTROL_CHARACTERS
+
+        # Check at the request level
+        if request_configuration is not None:
+            return request_configuration
+
+        # Check at the client level
+        if client_configuration is not None:
+            return client_configuration
+
+        # Check at the global level
+        if global_configuration is True:
+            return True
+
+        return False
