@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 from __future__ import absolute_import
@@ -59,11 +59,15 @@ class BudgetClient(object):
 
         :param obj circuit_breaker_strategy: (optional)
             A circuit breaker strategy to apply to all calls made by this service client (i.e. at the client level).
-            This client will not have circuit breakers enabled by default, users can use their own circuit breaker strategy or the convenient :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` provided by the SDK to enable it.
+            This client uses :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` as default if no circuit breaker strategy is provided.
             The specifics of circuit breaker strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/circuit_breakers.html>`__.
 
         :param function circuit_breaker_callback: (optional)
             Callback function to receive any exceptions triggerred by the circuit breaker.
+
+        :param allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this client should allow control characters in the response object. By default, the client will not
+            allow control characters to be in the response object.
         """
         validate_config(config, signer=kwargs.get('signer'))
         if 'signer' in kwargs:
@@ -92,6 +96,10 @@ class BudgetClient(object):
         }
         if 'timeout' in kwargs:
             base_client_init_kwargs['timeout'] = kwargs.get('timeout')
+        if base_client_init_kwargs.get('circuit_breaker_strategy') is None:
+            base_client_init_kwargs['circuit_breaker_strategy'] = circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY
+        if 'allow_control_chars' in kwargs:
+            base_client_init_kwargs['allow_control_chars'] = kwargs.get('allow_control_chars')
         self.base_client = BaseClient("budget", config, signer, budget_type_mapping, **base_client_init_kwargs)
         self.retry_strategy = kwargs.get('retry_strategy')
         self.circuit_breaker_callback = kwargs.get('circuit_breaker_callback')
@@ -102,14 +110,14 @@ class BudgetClient(object):
 
 
         :param str budget_id: (required)
-            The unique Budget OCID
+            The unique budget OCID.
 
         :param oci.budget.models.CreateAlertRuleDetails create_alert_rule_details: (required)
             Details for the new Alert Rule.
 
         :param str opc_retry_token: (optional)
-            A token that uniquely identifies a request so it can be retried in case of a timeout or
-            server error without risk of executing that same action again. Retry tokens expire after 24
+            A token that uniquely identifies a request so it can be retried, in case of a timeout or
+            server error, without risk of executing that same action again. Retry tokens expire after 24
             hours, but can be invalidated before then due to conflicting operations. For example, if a resource
             has been deleted and purged from the system, then a retry of the original creation request
             might be rejected.
@@ -125,17 +133,24 @@ class BudgetClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.budget.models.AlertRule`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/budget/create_alert_rule.py.html>`__ to see an example of how to use create_alert_rule API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/budget/create_alert_rule.py.html>`__ to see an example of how to use create_alert_rule API.
         """
         resource_path = "/budgets/{budgetId}/alertRules"
         method = "POST"
+        operation_name = "create_alert_rule"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/budgets/20190111/AlertRule/CreateAlertRule"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_retry_token",
             "opc_request_id"
@@ -180,7 +195,10 @@ class BudgetClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=create_alert_rule_details,
-                response_type="AlertRule")
+                response_type="AlertRule",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -188,19 +206,22 @@ class BudgetClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=create_alert_rule_details,
-                response_type="AlertRule")
+                response_type="AlertRule",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def create_budget(self, create_budget_details, **kwargs):
         """
-        Creates a new Budget.
+        Creates a new budget.
 
 
         :param oci.budget.models.CreateBudgetDetails create_budget_details: (required)
-            Details for the new Budget.
+            Details for the new budget.
 
         :param str opc_retry_token: (optional)
-            A token that uniquely identifies a request so it can be retried in case of a timeout or
-            server error without risk of executing that same action again. Retry tokens expire after 24
+            A token that uniquely identifies a request so it can be retried, in case of a timeout or
+            server error, without risk of executing that same action again. Retry tokens expire after 24
             hours, but can be invalidated before then due to conflicting operations. For example, if a resource
             has been deleted and purged from the system, then a retry of the original creation request
             might be rejected.
@@ -216,17 +237,24 @@ class BudgetClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.budget.models.Budget`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/budget/create_budget.py.html>`__ to see an example of how to use create_budget API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/budget/create_budget.py.html>`__ to see an example of how to use create_budget API.
         """
         resource_path = "/budgets"
         method = "POST"
+        operation_name = "create_budget"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/budgets/20190111/Budget/CreateBudget"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_retry_token",
             "opc_request_id"
@@ -260,14 +288,20 @@ class BudgetClient(object):
                 method=method,
                 header_params=header_params,
                 body=create_budget_details,
-                response_type="Budget")
+                response_type="Budget",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 header_params=header_params,
                 body=create_budget_details,
-                response_type="Budget")
+                response_type="Budget",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def delete_alert_rule(self, budget_id, alert_rule_id, **kwargs):
         """
@@ -275,10 +309,10 @@ class BudgetClient(object):
 
 
         :param str budget_id: (required)
-            The unique Budget OCID
+            The unique budget OCID.
 
         :param str alert_rule_id: (required)
-            The unique Alert Rule OCID
+            The unique Alert Rule OCID.
 
         :param str if_match: (optional)
             For optimistic concurrency control. In the PUT or DELETE call
@@ -298,17 +332,24 @@ class BudgetClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type None
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/budget/delete_alert_rule.py.html>`__ to see an example of how to use delete_alert_rule API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/budget/delete_alert_rule.py.html>`__ to see an example of how to use delete_alert_rule API.
         """
         resource_path = "/budgets/{budgetId}/alertRules/{alertRuleId}"
         method = "DELETE"
+        operation_name = "delete_alert_rule"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/budgets/20190111/AlertRule/DeleteAlertRule"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "if_match",
             "opc_request_id"
@@ -351,21 +392,27 @@ class BudgetClient(object):
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
-                header_params=header_params)
+                header_params=header_params,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
-                header_params=header_params)
+                header_params=header_params,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def delete_budget(self, budget_id, **kwargs):
         """
-        Deletes a specified Budget resource
+        Deletes a specified budget resource.
 
 
         :param str budget_id: (required)
-            The unique Budget OCID
+            The unique budget OCID.
 
         :param str if_match: (optional)
             For optimistic concurrency control. In the PUT or DELETE call
@@ -385,17 +432,24 @@ class BudgetClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type None
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/budget/delete_budget.py.html>`__ to see an example of how to use delete_budget API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/budget/delete_budget.py.html>`__ to see an example of how to use delete_budget API.
         """
         resource_path = "/budgets/{budgetId}"
         method = "DELETE"
+        operation_name = "delete_budget"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/budgets/20190111/Budget/DeleteBudget"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "if_match",
             "opc_request_id"
@@ -437,24 +491,30 @@ class BudgetClient(object):
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
-                header_params=header_params)
+                header_params=header_params,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
-                header_params=header_params)
+                header_params=header_params,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def get_alert_rule(self, budget_id, alert_rule_id, **kwargs):
         """
-        Gets an Alert Rule for a specified Budget.
+        Gets an Alert Rule for a specified budget.
 
 
         :param str budget_id: (required)
-            The unique Budget OCID
+            The unique budget OCID.
 
         :param str alert_rule_id: (required)
-            The unique Alert Rule OCID
+            The unique Alert Rule OCID.
 
         :param str opc_request_id: (optional)
             The client request ID for tracing.
@@ -467,17 +527,24 @@ class BudgetClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.budget.models.AlertRule`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/budget/get_alert_rule.py.html>`__ to see an example of how to use get_alert_rule API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/budget/get_alert_rule.py.html>`__ to see an example of how to use get_alert_rule API.
         """
         resource_path = "/budgets/{budgetId}/alertRules/{alertRuleId}"
         method = "GET"
+        operation_name = "get_alert_rule"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/budgets/20190111/AlertRule/GetAlertRule"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_request_id"
         ]
@@ -519,22 +586,28 @@ class BudgetClient(object):
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="AlertRule")
+                response_type="AlertRule",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="AlertRule")
+                response_type="AlertRule",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def get_budget(self, budget_id, **kwargs):
         """
-        Gets a Budget by identifier
+        Gets a budget by the identifier.
 
 
         :param str budget_id: (required)
-            The unique Budget OCID
+            The unique budget OCID.
 
         :param str opc_request_id: (optional)
             The client request ID for tracing.
@@ -547,17 +620,24 @@ class BudgetClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.budget.models.Budget`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/budget/get_budget.py.html>`__ to see an example of how to use get_budget API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/budget/get_budget.py.html>`__ to see an example of how to use get_budget API.
         """
         resource_path = "/budgets/{budgetId}"
         method = "GET"
+        operation_name = "get_budget"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/budgets/20190111/Budget/GetBudget"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_request_id"
         ]
@@ -598,22 +678,28 @@ class BudgetClient(object):
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="Budget")
+                response_type="Budget",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="Budget")
+                response_type="Budget",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def list_alert_rules(self, budget_id, **kwargs):
         """
-        Returns a list of Alert Rules for a specified Budget.
+        Returns a list of Alert Rules for a specified budget.
 
 
         :param str budget_id: (required)
-            The unique Budget OCID
+            The unique budget OCID.
 
         :param int limit: (optional)
             The maximum number of items to return.
@@ -639,7 +725,7 @@ class BudgetClient(object):
             Allowed values are: "ACTIVE", "INACTIVE"
 
         :param str display_name: (optional)
-            A user-friendly name. Does not have to be unique, and it's changeable.
+            A user-friendly name. This does not have to be unique, and it's changeable.
 
             Example: `My new resource`
 
@@ -654,17 +740,24 @@ class BudgetClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type list of :class:`~oci.budget.models.AlertRuleSummary`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/budget/list_alert_rules.py.html>`__ to see an example of how to use list_alert_rules API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/budget/list_alert_rules.py.html>`__ to see an example of how to use list_alert_rules API.
         """
         resource_path = "/budgets/{budgetId}/alertRules"
         method = "GET"
+        operation_name = "list_alert_rules"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/budgets/20190111/AlertRuleSummary/ListAlertRules"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "limit",
             "page",
@@ -743,7 +836,10 @@ class BudgetClient(object):
                 path_params=path_params,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="list[AlertRuleSummary]")
+                response_type="list[AlertRuleSummary]",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -751,20 +847,21 @@ class BudgetClient(object):
                 path_params=path_params,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="list[AlertRuleSummary]")
+                response_type="list[AlertRuleSummary]",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def list_budgets(self, compartment_id, **kwargs):
         """
-        Gets a list of Budgets in a compartment.
+        Gets a list of budgets in a compartment.
 
-        By default, ListBudgets returns budgets of 'COMPARTMENT' target type and the budget records with only ONE target compartment OCID.
+        By default, ListBudgets returns budgets of the 'COMPARTMENT' target type, and the budget records with only one target compartment OCID.
 
-        To list ALL budgets, set the targetType query parameter to ALL.
-        Example:
-          'targetType=ALL'
+        To list all budgets, set the targetType query parameter to ALL (for example: 'targetType=ALL').
 
-        Additional targetTypes would be available in future releases. Clients should ignore new targetType
-        or upgrade to latest version of client SDK to handle new targetType.
+        Additional targetTypes would be available in future releases. Clients should ignore new targetTypes,
+        or upgrade to the latest version of the client SDK to handle new targetTypes.
 
 
         :param str compartment_id: (required)
@@ -794,12 +891,12 @@ class BudgetClient(object):
             Allowed values are: "ACTIVE", "INACTIVE"
 
         :param str display_name: (optional)
-            A user-friendly name. Does not have to be unique, and it's changeable.
+            A user-friendly name. This does not have to be unique, and it's changeable.
 
             Example: `My new resource`
 
         :param str target_type: (optional)
-            The type of target to filter by.
+            The type of target to filter by:
               * ALL - List all budgets
               * COMPARTMENT - List all budgets with targetType == \"COMPARTMENT\"
               * TAG - List all budgets with targetType == \"TAG\"
@@ -817,17 +914,24 @@ class BudgetClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type list of :class:`~oci.budget.models.BudgetSummary`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/budget/list_budgets.py.html>`__ to see an example of how to use list_budgets API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/budget/list_budgets.py.html>`__ to see an example of how to use list_budgets API.
         """
         resource_path = "/budgets"
         method = "GET"
+        operation_name = "list_budgets"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/budgets/20190111/BudgetSummary/ListBudgets"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "limit",
             "page",
@@ -905,14 +1009,20 @@ class BudgetClient(object):
                 method=method,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="list[BudgetSummary]")
+                response_type="list[BudgetSummary]",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="list[BudgetSummary]")
+                response_type="list[BudgetSummary]",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def update_alert_rule(self, budget_id, alert_rule_id, update_alert_rule_details, **kwargs):
         """
@@ -920,10 +1030,10 @@ class BudgetClient(object):
 
 
         :param str budget_id: (required)
-            The unique Budget OCID
+            The unique budget OCID.
 
         :param str alert_rule_id: (required)
-            The unique Alert Rule OCID
+            The unique Alert Rule OCID.
 
         :param oci.budget.models.UpdateAlertRuleDetails update_alert_rule_details: (required)
             The information to be updated.
@@ -946,17 +1056,24 @@ class BudgetClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.budget.models.AlertRule`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/budget/update_alert_rule.py.html>`__ to see an example of how to use update_alert_rule API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/budget/update_alert_rule.py.html>`__ to see an example of how to use update_alert_rule API.
         """
         resource_path = "/budgets/{budgetId}/alertRules/{alertRuleId}"
         method = "PUT"
+        operation_name = "update_alert_rule"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/budgets/20190111/AlertRule/UpdateAlertRule"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "if_match",
             "opc_request_id"
@@ -1001,7 +1118,10 @@ class BudgetClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=update_alert_rule_details,
-                response_type="AlertRule")
+                response_type="AlertRule",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -1009,15 +1129,18 @@ class BudgetClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=update_alert_rule_details,
-                response_type="AlertRule")
+                response_type="AlertRule",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def update_budget(self, budget_id, update_budget_details, **kwargs):
         """
-        Update a Budget identified by the OCID
+        Update a budget identified by the OCID.
 
 
         :param str budget_id: (required)
-            The unique Budget OCID
+            The unique budget OCID.
 
         :param oci.budget.models.UpdateBudgetDetails update_budget_details: (required)
             The information to be updated.
@@ -1040,17 +1163,24 @@ class BudgetClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.budget.models.Budget`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/budget/update_budget.py.html>`__ to see an example of how to use update_budget API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/budget/update_budget.py.html>`__ to see an example of how to use update_budget API.
         """
         resource_path = "/budgets/{budgetId}"
         method = "PUT"
+        operation_name = "update_budget"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/budgets/20190111/Budget/UpdateBudget"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "if_match",
             "opc_request_id"
@@ -1094,7 +1224,10 @@ class BudgetClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=update_budget_details,
-                response_type="Budget")
+                response_type="Budget",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -1102,4 +1235,7 @@ class BudgetClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=update_budget_details,
-                response_type="Budget")
+                response_type="Budget",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
