@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 from .task_summary import TaskSummary
@@ -10,7 +10,7 @@ from oci.decorators import init_model_state_from_kwargs
 @init_model_state_from_kwargs
 class TaskSummaryFromRestTask(TaskSummary):
     """
-    The information about the Generic REST task.
+    The information about the Generic REST task. The endpoint and cancelEndpoint  properties are deprecated, use the properties executeRestCallConfig, cancelRestCallConfig and pollRestCallConfig for execute, cancel and polling of the calls.
     """
 
     #: A constant which can be used with the method_type property of a TaskSummaryFromRestTask.
@@ -41,6 +41,10 @@ class TaskSummaryFromRestTask(TaskSummary):
     #: This constant has a value of "ASYNC_OCI_WORKREQUEST"
     API_CALL_MODE_ASYNC_OCI_WORKREQUEST = "ASYNC_OCI_WORKREQUEST"
 
+    #: A constant which can be used with the api_call_mode property of a TaskSummaryFromRestTask.
+    #: This constant has a value of "ASYNC_GENERIC"
+    API_CALL_MODE_ASYNC_GENERIC = "ASYNC_GENERIC"
+
     #: A constant which can be used with the cancel_method_type property of a TaskSummaryFromRestTask.
     #: This constant has a value of "GET"
     CANCEL_METHOD_TYPE_GET = "GET"
@@ -69,7 +73,8 @@ class TaskSummaryFromRestTask(TaskSummary):
 
         :param model_type:
             The value to assign to the model_type property of this TaskSummaryFromRestTask.
-            Allowed values for this property are: "INTEGRATION_TASK", "DATA_LOADER_TASK", "PIPELINE_TASK", "SQL_TASK", "OCI_DATAFLOW_TASK", "REST_TASK"
+            Allowed values for this property are: "INTEGRATION_TASK", "DATA_LOADER_TASK", "PIPELINE_TASK", "SQL_TASK", "OCI_DATAFLOW_TASK", "REST_TASK", 'UNKNOWN_ENUM_VALUE'.
+            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
         :type model_type: str
 
         :param key:
@@ -136,13 +141,18 @@ class TaskSummaryFromRestTask(TaskSummary):
             The value to assign to the auth_details property of this TaskSummaryFromRestTask.
         :type auth_details: oci.data_integration.models.AuthDetails
 
+        :param auth_config:
+            The value to assign to the auth_config property of this TaskSummaryFromRestTask.
+        :type auth_config: oci.data_integration.models.AuthConfig
+
         :param endpoint:
             The value to assign to the endpoint property of this TaskSummaryFromRestTask.
         :type endpoint: oci.data_integration.models.Expression
 
         :param method_type:
             The value to assign to the method_type property of this TaskSummaryFromRestTask.
-            Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT"
+            Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT", 'UNKNOWN_ENUM_VALUE'.
+            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
         :type method_type: str
 
         :param headers:
@@ -155,7 +165,8 @@ class TaskSummaryFromRestTask(TaskSummary):
 
         :param api_call_mode:
             The value to assign to the api_call_mode property of this TaskSummaryFromRestTask.
-            Allowed values for this property are: "SYNCHRONOUS", "ASYNC_OCI_WORKREQUEST"
+            Allowed values for this property are: "SYNCHRONOUS", "ASYNC_OCI_WORKREQUEST", "ASYNC_GENERIC", 'UNKNOWN_ENUM_VALUE'.
+            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
         :type api_call_mode: str
 
         :param cancel_endpoint:
@@ -164,9 +175,22 @@ class TaskSummaryFromRestTask(TaskSummary):
 
         :param cancel_method_type:
             The value to assign to the cancel_method_type property of this TaskSummaryFromRestTask.
-            Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT"
+            Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT", 'UNKNOWN_ENUM_VALUE'.
+            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
         :type cancel_method_type: str
 
+        :param execute_rest_call_config:
+            The value to assign to the execute_rest_call_config property of this TaskSummaryFromRestTask.
+        :type execute_rest_call_config: oci.data_integration.models.ExecuteRestCallConfig
+
+        :param cancel_rest_call_config:
+            The value to assign to the cancel_rest_call_config property of this TaskSummaryFromRestTask.
+        :type cancel_rest_call_config: oci.data_integration.models.CancelRestCallConfig
+
+        :param poll_rest_call_config:
+            The value to assign to the poll_rest_call_config property of this TaskSummaryFromRestTask.
+        :type poll_rest_call_config: oci.data_integration.models.PollRestCallConfig
+
         """
         self.swagger_types = {
             'model_type': 'str',
@@ -186,13 +210,17 @@ class TaskSummaryFromRestTask(TaskSummary):
             'metadata': 'ObjectMetadata',
             'key_map': 'dict(str, str)',
             'auth_details': 'AuthDetails',
+            'auth_config': 'AuthConfig',
             'endpoint': 'Expression',
             'method_type': 'str',
             'headers': 'object',
             'json_data': 'str',
             'api_call_mode': 'str',
             'cancel_endpoint': 'Expression',
-            'cancel_method_type': 'str'
+            'cancel_method_type': 'str',
+            'execute_rest_call_config': 'ExecuteRestCallConfig',
+            'cancel_rest_call_config': 'CancelRestCallConfig',
+            'poll_rest_call_config': 'PollRestCallConfig'
         }
 
         self.attribute_map = {
@@ -213,13 +241,17 @@ class TaskSummaryFromRestTask(TaskSummary):
             'metadata': 'metadata',
             'key_map': 'keyMap',
             'auth_details': 'authDetails',
+            'auth_config': 'authConfig',
             'endpoint': 'endpoint',
             'method_type': 'methodType',
             'headers': 'headers',
             'json_data': 'jsonData',
             'api_call_mode': 'apiCallMode',
             'cancel_endpoint': 'cancelEndpoint',
-            'cancel_method_type': 'cancelMethodType'
+            'cancel_method_type': 'cancelMethodType',
+            'execute_rest_call_config': 'executeRestCallConfig',
+            'cancel_rest_call_config': 'cancelRestCallConfig',
+            'poll_rest_call_config': 'pollRestCallConfig'
         }
 
         self._model_type = None
@@ -239,6 +271,7 @@ class TaskSummaryFromRestTask(TaskSummary):
         self._metadata = None
         self._key_map = None
         self._auth_details = None
+        self._auth_config = None
         self._endpoint = None
         self._method_type = None
         self._headers = None
@@ -246,6 +279,9 @@ class TaskSummaryFromRestTask(TaskSummary):
         self._api_call_mode = None
         self._cancel_endpoint = None
         self._cancel_method_type = None
+        self._execute_rest_call_config = None
+        self._cancel_rest_call_config = None
+        self._poll_rest_call_config = None
         self._model_type = 'REST_TASK'
 
     @property
@@ -268,6 +304,26 @@ class TaskSummaryFromRestTask(TaskSummary):
         """
         self._auth_details = auth_details
 
+    @property
+    def auth_config(self):
+        """
+        Gets the auth_config of this TaskSummaryFromRestTask.
+
+        :return: The auth_config of this TaskSummaryFromRestTask.
+        :rtype: oci.data_integration.models.AuthConfig
+        """
+        return self._auth_config
+
+    @auth_config.setter
+    def auth_config(self, auth_config):
+        """
+        Sets the auth_config of this TaskSummaryFromRestTask.
+
+        :param auth_config: The auth_config of this TaskSummaryFromRestTask.
+        :type: oci.data_integration.models.AuthConfig
+        """
+        self._auth_config = auth_config
+
     @property
     def endpoint(self):
         """
@@ -292,9 +348,10 @@ class TaskSummaryFromRestTask(TaskSummary):
     def method_type(self):
         """
         Gets the method_type of this TaskSummaryFromRestTask.
-        The REST method to use.
+        The REST method to use. This property is deprecated, use ExecuteRestCallConfig's methodType property instead.
 
-        Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT"
+        Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT", 'UNKNOWN_ENUM_VALUE'.
+        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
 
 
         :return: The method_type of this TaskSummaryFromRestTask.
@@ -306,7 +363,7 @@ class TaskSummaryFromRestTask(TaskSummary):
     def method_type(self, method_type):
         """
         Sets the method_type of this TaskSummaryFromRestTask.
-        The REST method to use.
+        The REST method to use. This property is deprecated, use ExecuteRestCallConfig's methodType property instead.
 
 
         :param method_type: The method_type of this TaskSummaryFromRestTask.
@@ -314,18 +371,13 @@ class TaskSummaryFromRestTask(TaskSummary):
         """
         allowed_values = ["GET", "POST", "PATCH", "DELETE", "PUT"]
         if not value_allowed_none_or_none_sentinel(method_type, allowed_values):
-            raise ValueError(
-                "Invalid value for `method_type`, must be None or one of {0}"
-                .format(allowed_values)
-            )
+            method_type = 'UNKNOWN_ENUM_VALUE'
         self._method_type = method_type
 
     @property
     def headers(self):
         """
         Gets the headers of this TaskSummaryFromRestTask.
-        The headers for the REST call.
-
 
         :return: The headers of this TaskSummaryFromRestTask.
         :rtype: object
@@ -336,8 +388,6 @@ class TaskSummaryFromRestTask(TaskSummary):
     def headers(self, headers):
         """
         Sets the headers of this TaskSummaryFromRestTask.
-        The headers for the REST call.
-
 
         :param headers: The headers of this TaskSummaryFromRestTask.
         :type: object
@@ -348,7 +398,7 @@ class TaskSummaryFromRestTask(TaskSummary):
     def json_data(self):
         """
         Gets the json_data of this TaskSummaryFromRestTask.
-        JSON data for payload body.
+        JSON data for payload body. This property is deprecated, use ExecuteRestCallConfig's payload config param instead.
 
 
         :return: The json_data of this TaskSummaryFromRestTask.
@@ -360,7 +410,7 @@ class TaskSummaryFromRestTask(TaskSummary):
     def json_data(self, json_data):
         """
         Sets the json_data of this TaskSummaryFromRestTask.
-        JSON data for payload body.
+        JSON data for payload body. This property is deprecated, use ExecuteRestCallConfig's payload config param instead.
 
 
         :param json_data: The json_data of this TaskSummaryFromRestTask.
@@ -372,9 +422,10 @@ class TaskSummaryFromRestTask(TaskSummary):
     def api_call_mode(self):
         """
         Gets the api_call_mode of this TaskSummaryFromRestTask.
-        The invocation type to be used for Generic REST invocation.
+        The REST invocation pattern to use. ASYNC_OCI_WORKREQUEST is being deprecated as well as cancelEndpoint/MethodType.
 
-        Allowed values for this property are: "SYNCHRONOUS", "ASYNC_OCI_WORKREQUEST"
+        Allowed values for this property are: "SYNCHRONOUS", "ASYNC_OCI_WORKREQUEST", "ASYNC_GENERIC", 'UNKNOWN_ENUM_VALUE'.
+        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
 
 
         :return: The api_call_mode of this TaskSummaryFromRestTask.
@@ -386,18 +437,15 @@ class TaskSummaryFromRestTask(TaskSummary):
     def api_call_mode(self, api_call_mode):
         """
         Sets the api_call_mode of this TaskSummaryFromRestTask.
-        The invocation type to be used for Generic REST invocation.
+        The REST invocation pattern to use. ASYNC_OCI_WORKREQUEST is being deprecated as well as cancelEndpoint/MethodType.
 
 
         :param api_call_mode: The api_call_mode of this TaskSummaryFromRestTask.
         :type: str
         """
-        allowed_values = ["SYNCHRONOUS", "ASYNC_OCI_WORKREQUEST"]
+        allowed_values = ["SYNCHRONOUS", "ASYNC_OCI_WORKREQUEST", "ASYNC_GENERIC"]
         if not value_allowed_none_or_none_sentinel(api_call_mode, allowed_values):
-            raise ValueError(
-                "Invalid value for `api_call_mode`, must be None or one of {0}"
-                .format(allowed_values)
-            )
+            api_call_mode = 'UNKNOWN_ENUM_VALUE'
         self._api_call_mode = api_call_mode
 
     @property
@@ -426,7 +474,8 @@ class TaskSummaryFromRestTask(TaskSummary):
         Gets the cancel_method_type of this TaskSummaryFromRestTask.
         The REST method to use for canceling the original request.
 
-        Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT"
+        Allowed values for this property are: "GET", "POST", "PATCH", "DELETE", "PUT", 'UNKNOWN_ENUM_VALUE'.
+        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
 
 
         :return: The cancel_method_type of this TaskSummaryFromRestTask.
@@ -446,12 +495,69 @@ class TaskSummaryFromRestTask(TaskSummary):
         """
         allowed_values = ["GET", "POST", "PATCH", "DELETE", "PUT"]
         if not value_allowed_none_or_none_sentinel(cancel_method_type, allowed_values):
-            raise ValueError(
-                "Invalid value for `cancel_method_type`, must be None or one of {0}"
-                .format(allowed_values)
-            )
+            cancel_method_type = 'UNKNOWN_ENUM_VALUE'
         self._cancel_method_type = cancel_method_type
 
+    @property
+    def execute_rest_call_config(self):
+        """
+        Gets the execute_rest_call_config of this TaskSummaryFromRestTask.
+
+        :return: The execute_rest_call_config of this TaskSummaryFromRestTask.
+        :rtype: oci.data_integration.models.ExecuteRestCallConfig
+        """
+        return self._execute_rest_call_config
+
+    @execute_rest_call_config.setter
+    def execute_rest_call_config(self, execute_rest_call_config):
+        """
+        Sets the execute_rest_call_config of this TaskSummaryFromRestTask.
+
+        :param execute_rest_call_config: The execute_rest_call_config of this TaskSummaryFromRestTask.
+        :type: oci.data_integration.models.ExecuteRestCallConfig
+        """
+        self._execute_rest_call_config = execute_rest_call_config
+
+    @property
+    def cancel_rest_call_config(self):
+        """
+        Gets the cancel_rest_call_config of this TaskSummaryFromRestTask.
+
+        :return: The cancel_rest_call_config of this TaskSummaryFromRestTask.
+        :rtype: oci.data_integration.models.CancelRestCallConfig
+        """
+        return self._cancel_rest_call_config
+
+    @cancel_rest_call_config.setter
+    def cancel_rest_call_config(self, cancel_rest_call_config):
+        """
+        Sets the cancel_rest_call_config of this TaskSummaryFromRestTask.
+
+        :param cancel_rest_call_config: The cancel_rest_call_config of this TaskSummaryFromRestTask.
+        :type: oci.data_integration.models.CancelRestCallConfig
+        """
+        self._cancel_rest_call_config = cancel_rest_call_config
+
+    @property
+    def poll_rest_call_config(self):
+        """
+        Gets the poll_rest_call_config of this TaskSummaryFromRestTask.
+
+        :return: The poll_rest_call_config of this TaskSummaryFromRestTask.
+        :rtype: oci.data_integration.models.PollRestCallConfig
+        """
+        return self._poll_rest_call_config
+
+    @poll_rest_call_config.setter
+    def poll_rest_call_config(self, poll_rest_call_config):
+        """
+        Sets the poll_rest_call_config of this TaskSummaryFromRestTask.
+
+        :param poll_rest_call_config: The poll_rest_call_config of this TaskSummaryFromRestTask.
+        :type: oci.data_integration.models.PollRestCallConfig
+        """
+        self._poll_rest_call_config = poll_rest_call_config
+
     def __repr__(self):
         return formatted_flat_dict(self)
 
