@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -43,6 +43,10 @@ class CreateVmClusterDetails(object):
             The value to assign to the cpu_core_count property of this CreateVmClusterDetails.
         :type cpu_core_count: int
 
+        :param ocpu_count:
+            The value to assign to the ocpu_count property of this CreateVmClusterDetails.
+        :type ocpu_count: float
+
         :param memory_size_in_gbs:
             The value to assign to the memory_size_in_gbs property of this CreateVmClusterDetails.
         :type memory_size_in_gbs: int
@@ -55,6 +59,10 @@ class CreateVmClusterDetails(object):
             The value to assign to the data_storage_size_in_tbs property of this CreateVmClusterDetails.
         :type data_storage_size_in_tbs: float
 
+        :param data_storage_size_in_gbs:
+            The value to assign to the data_storage_size_in_gbs property of this CreateVmClusterDetails.
+        :type data_storage_size_in_gbs: float
+
         :param ssh_public_keys:
             The value to assign to the ssh_public_keys property of this CreateVmClusterDetails.
         :type ssh_public_keys: list[str]
@@ -96,15 +104,21 @@ class CreateVmClusterDetails(object):
             The value to assign to the defined_tags property of this CreateVmClusterDetails.
         :type defined_tags: dict(str, dict(str, object))
 
+        :param data_collection_options:
+            The value to assign to the data_collection_options property of this CreateVmClusterDetails.
+        :type data_collection_options: oci.database.models.DataCollectionOptions
+
         """
         self.swagger_types = {
             'compartment_id': 'str',
             'display_name': 'str',
             'exadata_infrastructure_id': 'str',
             'cpu_core_count': 'int',
+            'ocpu_count': 'float',
             'memory_size_in_gbs': 'int',
             'db_node_storage_size_in_gbs': 'int',
             'data_storage_size_in_tbs': 'float',
+            'data_storage_size_in_gbs': 'float',
             'ssh_public_keys': 'list[str]',
             'vm_cluster_network_id': 'str',
             'license_model': 'str',
@@ -114,7 +128,8 @@ class CreateVmClusterDetails(object):
             'gi_version': 'str',
             'db_servers': 'list[str]',
             'freeform_tags': 'dict(str, str)',
-            'defined_tags': 'dict(str, dict(str, object))'
+            'defined_tags': 'dict(str, dict(str, object))',
+            'data_collection_options': 'DataCollectionOptions'
         }
 
         self.attribute_map = {
@@ -122,9 +137,11 @@ class CreateVmClusterDetails(object):
             'display_name': 'displayName',
             'exadata_infrastructure_id': 'exadataInfrastructureId',
             'cpu_core_count': 'cpuCoreCount',
+            'ocpu_count': 'ocpuCount',
             'memory_size_in_gbs': 'memorySizeInGBs',
             'db_node_storage_size_in_gbs': 'dbNodeStorageSizeInGBs',
             'data_storage_size_in_tbs': 'dataStorageSizeInTBs',
+            'data_storage_size_in_gbs': 'dataStorageSizeInGBs',
             'ssh_public_keys': 'sshPublicKeys',
             'vm_cluster_network_id': 'vmClusterNetworkId',
             'license_model': 'licenseModel',
@@ -134,16 +151,19 @@ class CreateVmClusterDetails(object):
             'gi_version': 'giVersion',
             'db_servers': 'dbServers',
             'freeform_tags': 'freeformTags',
-            'defined_tags': 'definedTags'
+            'defined_tags': 'definedTags',
+            'data_collection_options': 'dataCollectionOptions'
         }
 
         self._compartment_id = None
         self._display_name = None
         self._exadata_infrastructure_id = None
         self._cpu_core_count = None
+        self._ocpu_count = None
         self._memory_size_in_gbs = None
         self._db_node_storage_size_in_gbs = None
         self._data_storage_size_in_tbs = None
+        self._data_storage_size_in_gbs = None
         self._ssh_public_keys = None
         self._vm_cluster_network_id = None
         self._license_model = None
@@ -154,6 +174,7 @@ class CreateVmClusterDetails(object):
         self._db_servers = None
         self._freeform_tags = None
         self._defined_tags = None
+        self._data_collection_options = None
 
     @property
     def compartment_id(self):
@@ -259,6 +280,30 @@ class CreateVmClusterDetails(object):
         """
         self._cpu_core_count = cpu_core_count
 
+    @property
+    def ocpu_count(self):
+        """
+        Gets the ocpu_count of this CreateVmClusterDetails.
+        The number of OCPU cores to enable for the VM cluster. Only one decimal place is allowed for the fractional part.
+
+
+        :return: The ocpu_count of this CreateVmClusterDetails.
+        :rtype: float
+        """
+        return self._ocpu_count
+
+    @ocpu_count.setter
+    def ocpu_count(self, ocpu_count):
+        """
+        Sets the ocpu_count of this CreateVmClusterDetails.
+        The number of OCPU cores to enable for the VM cluster. Only one decimal place is allowed for the fractional part.
+
+
+        :param ocpu_count: The ocpu_count of this CreateVmClusterDetails.
+        :type: float
+        """
+        self._ocpu_count = ocpu_count
+
     @property
     def memory_size_in_gbs(self):
         """
@@ -331,6 +376,30 @@ class CreateVmClusterDetails(object):
         """
         self._data_storage_size_in_tbs = data_storage_size_in_tbs
 
+    @property
+    def data_storage_size_in_gbs(self):
+        """
+        Gets the data_storage_size_in_gbs of this CreateVmClusterDetails.
+        The data disk group size to be allocated in GBs.
+
+
+        :return: The data_storage_size_in_gbs of this CreateVmClusterDetails.
+        :rtype: float
+        """
+        return self._data_storage_size_in_gbs
+
+    @data_storage_size_in_gbs.setter
+    def data_storage_size_in_gbs(self, data_storage_size_in_gbs):
+        """
+        Sets the data_storage_size_in_gbs of this CreateVmClusterDetails.
+        The data disk group size to be allocated in GBs.
+
+
+        :param data_storage_size_in_gbs: The data_storage_size_in_gbs of this CreateVmClusterDetails.
+        :type: float
+        """
+        self._data_storage_size_in_gbs = data_storage_size_in_gbs
+
     @property
     def ssh_public_keys(self):
         """
@@ -603,6 +672,26 @@ class CreateVmClusterDetails(object):
         """
         self._defined_tags = defined_tags
 
+    @property
+    def data_collection_options(self):
+        """
+        Gets the data_collection_options of this CreateVmClusterDetails.
+
+        :return: The data_collection_options of this CreateVmClusterDetails.
+        :rtype: oci.database.models.DataCollectionOptions
+        """
+        return self._data_collection_options
+
+    @data_collection_options.setter
+    def data_collection_options(self, data_collection_options):
+        """
+        Sets the data_collection_options of this CreateVmClusterDetails.
+
+        :param data_collection_options: The data_collection_options of this CreateVmClusterDetails.
+        :type: oci.database.models.DataCollectionOptions
+        """
+        self._data_collection_options = data_collection_options
+
     def __repr__(self):
         return formatted_flat_dict(self)
 
