@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -104,6 +104,10 @@ class DbServerSummary(object):
             The value to assign to the time_created property of this DbServerSummary.
         :type time_created: datetime
 
+        :param db_server_patching_details:
+            The value to assign to the db_server_patching_details property of this DbServerSummary.
+        :type db_server_patching_details: oci.database.models.DbServerPatchingDetails
+
         :param freeform_tags:
             The value to assign to the freeform_tags property of this DbServerSummary.
         :type freeform_tags: dict(str, str)
@@ -129,6 +133,7 @@ class DbServerSummary(object):
             'max_memory_in_gbs': 'int',
             'max_db_node_storage_in_gbs': 'int',
             'time_created': 'datetime',
+            'db_server_patching_details': 'DbServerPatchingDetails',
             'freeform_tags': 'dict(str, str)',
             'defined_tags': 'dict(str, dict(str, object))'
         }
@@ -149,6 +154,7 @@ class DbServerSummary(object):
             'max_memory_in_gbs': 'maxMemoryInGBs',
             'max_db_node_storage_in_gbs': 'maxDbNodeStorageInGBs',
             'time_created': 'timeCreated',
+            'db_server_patching_details': 'dbServerPatchingDetails',
             'freeform_tags': 'freeformTags',
             'defined_tags': 'definedTags'
         }
@@ -168,6 +174,7 @@ class DbServerSummary(object):
         self._max_memory_in_gbs = None
         self._max_db_node_storage_in_gbs = None
         self._time_created = None
+        self._db_server_patching_details = None
         self._freeform_tags = None
         self._defined_tags = None
 
@@ -557,6 +564,26 @@ class DbServerSummary(object):
         """
         self._time_created = time_created
 
+    @property
+    def db_server_patching_details(self):
+        """
+        Gets the db_server_patching_details of this DbServerSummary.
+
+        :return: The db_server_patching_details of this DbServerSummary.
+        :rtype: oci.database.models.DbServerPatchingDetails
+        """
+        return self._db_server_patching_details
+
+    @db_server_patching_details.setter
+    def db_server_patching_details(self, db_server_patching_details):
+        """
+        Sets the db_server_patching_details of this DbServerSummary.
+
+        :param db_server_patching_details: The db_server_patching_details of this DbServerSummary.
+        :type: oci.database.models.DbServerPatchingDetails
+        """
+        self._db_server_patching_details = db_server_patching_details
+
     @property
     def freeform_tags(self):
         """
