@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -108,6 +108,10 @@ class VmCluster(object):
             The value to assign to the cpus_enabled property of this VmCluster.
         :type cpus_enabled: int
 
+        :param ocpus_enabled:
+            The value to assign to the ocpus_enabled property of this VmCluster.
+        :type ocpus_enabled: float
+
         :param memory_size_in_gbs:
             The value to assign to the memory_size_in_gbs property of this VmCluster.
         :type memory_size_in_gbs: int
@@ -120,6 +124,10 @@ class VmCluster(object):
             The value to assign to the data_storage_size_in_tbs property of this VmCluster.
         :type data_storage_size_in_tbs: float
 
+        :param data_storage_size_in_gbs:
+            The value to assign to the data_storage_size_in_gbs property of this VmCluster.
+        :type data_storage_size_in_gbs: float
+
         :param shape:
             The value to assign to the shape property of this VmCluster.
         :type shape: str
@@ -154,6 +162,10 @@ class VmCluster(object):
             The value to assign to the defined_tags property of this VmCluster.
         :type defined_tags: dict(str, dict(str, object))
 
+        :param data_collection_options:
+            The value to assign to the data_collection_options property of this VmCluster.
+        :type data_collection_options: oci.database.models.DataCollectionOptions
+
         """
         self.swagger_types = {
             'id': 'str',
@@ -169,9 +181,11 @@ class VmCluster(object):
             'is_sparse_diskgroup_enabled': 'bool',
             'vm_cluster_network_id': 'str',
             'cpus_enabled': 'int',
+            'ocpus_enabled': 'float',
             'memory_size_in_gbs': 'int',
             'db_node_storage_size_in_gbs': 'int',
             'data_storage_size_in_tbs': 'float',
+            'data_storage_size_in_gbs': 'float',
             'shape': 'str',
             'gi_version': 'str',
             'system_version': 'str',
@@ -179,7 +193,8 @@ class VmCluster(object):
             'license_model': 'str',
             'db_servers': 'list[str]',
             'freeform_tags': 'dict(str, str)',
-            'defined_tags': 'dict(str, dict(str, object))'
+            'defined_tags': 'dict(str, dict(str, object))',
+            'data_collection_options': 'DataCollectionOptions'
         }
 
         self.attribute_map = {
@@ -196,9 +211,11 @@ class VmCluster(object):
             'is_sparse_diskgroup_enabled': 'isSparseDiskgroupEnabled',
             'vm_cluster_network_id': 'vmClusterNetworkId',
             'cpus_enabled': 'cpusEnabled',
+            'ocpus_enabled': 'ocpusEnabled',
             'memory_size_in_gbs': 'memorySizeInGBs',
             'db_node_storage_size_in_gbs': 'dbNodeStorageSizeInGBs',
             'data_storage_size_in_tbs': 'dataStorageSizeInTBs',
+            'data_storage_size_in_gbs': 'dataStorageSizeInGBs',
             'shape': 'shape',
             'gi_version': 'giVersion',
             'system_version': 'systemVersion',
@@ -206,7 +223,8 @@ class VmCluster(object):
             'license_model': 'licenseModel',
             'db_servers': 'dbServers',
             'freeform_tags': 'freeformTags',
-            'defined_tags': 'definedTags'
+            'defined_tags': 'definedTags',
+            'data_collection_options': 'dataCollectionOptions'
         }
 
         self._id = None
@@ -222,9 +240,11 @@ class VmCluster(object):
         self._is_sparse_diskgroup_enabled = None
         self._vm_cluster_network_id = None
         self._cpus_enabled = None
+        self._ocpus_enabled = None
         self._memory_size_in_gbs = None
         self._db_node_storage_size_in_gbs = None
         self._data_storage_size_in_tbs = None
+        self._data_storage_size_in_gbs = None
         self._shape = None
         self._gi_version = None
         self._system_version = None
@@ -233,6 +253,7 @@ class VmCluster(object):
         self._db_servers = None
         self._freeform_tags = None
         self._defined_tags = None
+        self._data_collection_options = None
 
     @property
     def id(self):
@@ -576,6 +597,30 @@ class VmCluster(object):
         """
         self._cpus_enabled = cpus_enabled
 
+    @property
+    def ocpus_enabled(self):
+        """
+        Gets the ocpus_enabled of this VmCluster.
+        The number of enabled OCPU cores.
+
+
+        :return: The ocpus_enabled of this VmCluster.
+        :rtype: float
+        """
+        return self._ocpus_enabled
+
+    @ocpus_enabled.setter
+    def ocpus_enabled(self, ocpus_enabled):
+        """
+        Sets the ocpus_enabled of this VmCluster.
+        The number of enabled OCPU cores.
+
+
+        :param ocpus_enabled: The ocpus_enabled of this VmCluster.
+        :type: float
+        """
+        self._ocpus_enabled = ocpus_enabled
+
     @property
     def memory_size_in_gbs(self):
         """
@@ -648,6 +693,30 @@ class VmCluster(object):
         """
         self._data_storage_size_in_tbs = data_storage_size_in_tbs
 
+    @property
+    def data_storage_size_in_gbs(self):
+        """
+        Gets the data_storage_size_in_gbs of this VmCluster.
+        Size of the DATA disk group in GBs.
+
+
+        :return: The data_storage_size_in_gbs of this VmCluster.
+        :rtype: float
+        """
+        return self._data_storage_size_in_gbs
+
+    @data_storage_size_in_gbs.setter
+    def data_storage_size_in_gbs(self, data_storage_size_in_gbs):
+        """
+        Sets the data_storage_size_in_gbs of this VmCluster.
+        Size of the DATA disk group in GBs.
+
+
+        :param data_storage_size_in_gbs: The data_storage_size_in_gbs of this VmCluster.
+        :type: float
+        """
+        self._data_storage_size_in_gbs = data_storage_size_in_gbs
+
     @property
     def shape(self):
         """
@@ -862,6 +931,26 @@ class VmCluster(object):
         """
         self._defined_tags = defined_tags
 
+    @property
+    def data_collection_options(self):
+        """
+        Gets the data_collection_options of this VmCluster.
+
+        :return: The data_collection_options of this VmCluster.
+        :rtype: oci.database.models.DataCollectionOptions
+        """
+        return self._data_collection_options
+
+    @data_collection_options.setter
+    def data_collection_options(self, data_collection_options):
+        """
+        Sets the data_collection_options of this VmCluster.
+
+        :param data_collection_options: The data_collection_options of this VmCluster.
+        :type: oci.database.models.DataCollectionOptions
+        """
+        self._data_collection_options = data_collection_options
+
     def __repr__(self):
         return formatted_flat_dict(self)
 
