@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 from __future__ import absolute_import
@@ -59,11 +59,15 @@ class TransferApplianceClient(object):
 
         :param obj circuit_breaker_strategy: (optional)
             A circuit breaker strategy to apply to all calls made by this service client (i.e. at the client level).
-            This client will not have circuit breakers enabled by default, users can use their own circuit breaker strategy or the convenient :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` provided by the SDK to enable it.
+            This client uses :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` as default if no circuit breaker strategy is provided.
             The specifics of circuit breaker strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/circuit_breakers.html>`__.
 
         :param function circuit_breaker_callback: (optional)
             Callback function to receive any exceptions triggerred by the circuit breaker.
+
+        :param allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this client should allow control characters in the response object. By default, the client will not
+            allow control characters to be in the response object.
         """
         validate_config(config, signer=kwargs.get('signer'))
         if 'signer' in kwargs:
@@ -92,6 +96,10 @@ class TransferApplianceClient(object):
         }
         if 'timeout' in kwargs:
             base_client_init_kwargs['timeout'] = kwargs.get('timeout')
+        if base_client_init_kwargs.get('circuit_breaker_strategy') is None:
+            base_client_init_kwargs['circuit_breaker_strategy'] = circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY
+        if 'allow_control_chars' in kwargs:
+            base_client_init_kwargs['allow_control_chars'] = kwargs.get('allow_control_chars')
         self.base_client = BaseClient("transfer_appliance", config, signer, dts_type_mapping, **base_client_init_kwargs)
         self.retry_strategy = kwargs.get('retry_strategy')
         self.circuit_breaker_callback = kwargs.get('circuit_breaker_callback')
@@ -117,17 +125,24 @@ class TransferApplianceClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.dts.models.TransferAppliance`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/dts/create_transfer_appliance.py.html>`__ to see an example of how to use create_transfer_appliance API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/dts/create_transfer_appliance.py.html>`__ to see an example of how to use create_transfer_appliance API.
         """
         resource_path = "/transferJobs/{id}/transferAppliances"
         method = "POST"
+        operation_name = "create_transfer_appliance"
+        api_reference_link = ""
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_retry_token",
             "create_transfer_appliance_details"
@@ -171,7 +186,10 @@ class TransferApplianceClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=kwargs.get('create_transfer_appliance_details'),
-                response_type="TransferAppliance")
+                response_type="TransferAppliance",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -179,7 +197,10 @@ class TransferApplianceClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=kwargs.get('create_transfer_appliance_details'),
-                response_type="TransferAppliance")
+                response_type="TransferAppliance",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def create_transfer_appliance_admin_credentials(self, id, transfer_appliance_label, admin_public_key, **kwargs):
         """
@@ -202,14 +223,20 @@ class TransferApplianceClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.dts.models.TransferApplianceCertificate`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/dts/create_transfer_appliance_admin_credentials.py.html>`__ to see an example of how to use create_transfer_appliance_admin_credentials API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/dts/create_transfer_appliance_admin_credentials.py.html>`__ to see an example of how to use create_transfer_appliance_admin_credentials API.
         """
         resource_path = "/transferJobs/{id}/transferAppliances/{transferApplianceLabel}/admin_credentials"
         method = "POST"
+        operation_name = "create_transfer_appliance_admin_credentials"
+        api_reference_link = ""
 
         expected_kwargs = ["retry_strategy"]
         extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
@@ -249,7 +276,10 @@ class TransferApplianceClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=admin_public_key,
-                response_type="TransferApplianceCertificate")
+                response_type="TransferApplianceCertificate",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -257,7 +287,10 @@ class TransferApplianceClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=admin_public_key,
-                response_type="TransferApplianceCertificate")
+                response_type="TransferApplianceCertificate",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def delete_transfer_appliance(self, id, transfer_appliance_label, **kwargs):
         """
@@ -278,14 +311,20 @@ class TransferApplianceClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type None
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/dts/delete_transfer_appliance.py.html>`__ to see an example of how to use delete_transfer_appliance API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/dts/delete_transfer_appliance.py.html>`__ to see an example of how to use delete_transfer_appliance API.
         """
         resource_path = "/transferJobs/{id}/transferAppliances/{transferApplianceLabel}"
         method = "DELETE"
+        operation_name = "delete_transfer_appliance"
+        api_reference_link = ""
 
         expected_kwargs = ["retry_strategy"]
         extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
@@ -323,13 +362,19 @@ class TransferApplianceClient(object):
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
-                header_params=header_params)
+                header_params=header_params,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
-                header_params=header_params)
+                header_params=header_params,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def get_transfer_appliance(self, id, transfer_appliance_label, **kwargs):
         """
@@ -350,14 +395,20 @@ class TransferApplianceClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.dts.models.TransferAppliance`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/dts/get_transfer_appliance.py.html>`__ to see an example of how to use get_transfer_appliance API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/dts/get_transfer_appliance.py.html>`__ to see an example of how to use get_transfer_appliance API.
         """
         resource_path = "/transferJobs/{id}/transferAppliances/{transferApplianceLabel}"
         method = "GET"
+        operation_name = "get_transfer_appliance"
+        api_reference_link = ""
 
         expected_kwargs = ["retry_strategy"]
         extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
@@ -396,14 +447,20 @@ class TransferApplianceClient(object):
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="TransferAppliance")
+                response_type="TransferAppliance",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="TransferAppliance")
+                response_type="TransferAppliance",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def get_transfer_appliance_certificate_authority_certificate(self, id, transfer_appliance_label, **kwargs):
         """
@@ -424,14 +481,20 @@ class TransferApplianceClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.dts.models.TransferApplianceCertificate`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/dts/get_transfer_appliance_certificate_authority_certificate.py.html>`__ to see an example of how to use get_transfer_appliance_certificate_authority_certificate API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/dts/get_transfer_appliance_certificate_authority_certificate.py.html>`__ to see an example of how to use get_transfer_appliance_certificate_authority_certificate API.
         """
         resource_path = "/transferJobs/{id}/transferAppliances/{transferApplianceLabel}/certificate_authority_certificate"
         method = "GET"
+        operation_name = "get_transfer_appliance_certificate_authority_certificate"
+        api_reference_link = ""
 
         expected_kwargs = ["retry_strategy"]
         extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
@@ -470,14 +533,20 @@ class TransferApplianceClient(object):
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="TransferApplianceCertificate")
+                response_type="TransferApplianceCertificate",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="TransferApplianceCertificate")
+                response_type="TransferApplianceCertificate",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def get_transfer_appliance_encryption_passphrase(self, id, transfer_appliance_label, **kwargs):
         """
@@ -498,14 +567,20 @@ class TransferApplianceClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.dts.models.TransferApplianceEncryptionPassphrase`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/dts/get_transfer_appliance_encryption_passphrase.py.html>`__ to see an example of how to use get_transfer_appliance_encryption_passphrase API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/dts/get_transfer_appliance_encryption_passphrase.py.html>`__ to see an example of how to use get_transfer_appliance_encryption_passphrase API.
         """
         resource_path = "/transferJobs/{id}/transferAppliances/{transferApplianceLabel}/encryptionPassphrase"
         method = "GET"
+        operation_name = "get_transfer_appliance_encryption_passphrase"
+        api_reference_link = ""
 
         expected_kwargs = ["retry_strategy"]
         extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
@@ -544,14 +619,20 @@ class TransferApplianceClient(object):
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="TransferApplianceEncryptionPassphrase")
+                response_type="TransferApplianceEncryptionPassphrase",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="TransferApplianceEncryptionPassphrase")
+                response_type="TransferApplianceEncryptionPassphrase",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def list_transfer_appliances(self, id, **kwargs):
         """
@@ -574,17 +655,24 @@ class TransferApplianceClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.dts.models.MultipleTransferAppliances`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/dts/list_transfer_appliances.py.html>`__ to see an example of how to use list_transfer_appliances API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/dts/list_transfer_appliances.py.html>`__ to see an example of how to use list_transfer_appliances API.
         """
         resource_path = "/transferJobs/{id}/transferAppliances"
         method = "GET"
+        operation_name = "list_transfer_appliances"
+        api_reference_link = ""
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "lifecycle_state"
         ]
@@ -636,7 +724,10 @@ class TransferApplianceClient(object):
                 path_params=path_params,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="MultipleTransferAppliances")
+                response_type="MultipleTransferAppliances",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -644,7 +735,10 @@ class TransferApplianceClient(object):
                 path_params=path_params,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="MultipleTransferAppliances")
+                response_type="MultipleTransferAppliances",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def update_transfer_appliance(self, id, transfer_appliance_label, update_transfer_appliance_details, **kwargs):
         """
@@ -672,17 +766,24 @@ class TransferApplianceClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.dts.models.TransferAppliance`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/dts/update_transfer_appliance.py.html>`__ to see an example of how to use update_transfer_appliance API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/dts/update_transfer_appliance.py.html>`__ to see an example of how to use update_transfer_appliance API.
         """
         resource_path = "/transferJobs/{id}/transferAppliances/{transferApplianceLabel}"
         method = "PUT"
+        operation_name = "update_transfer_appliance"
+        api_reference_link = ""
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "if_match"
         ]
@@ -725,7 +826,10 @@ class TransferApplianceClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=update_transfer_appliance_details,
-                response_type="TransferAppliance")
+                response_type="TransferAppliance",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -733,4 +837,7 @@ class TransferApplianceClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=update_transfer_appliance_details,
-                response_type="TransferAppliance")
+                response_type="TransferAppliance",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
