@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 from __future__ import absolute_import
@@ -60,11 +60,15 @@ class NotificationDataPlaneClient(object):
 
         :param obj circuit_breaker_strategy: (optional)
             A circuit breaker strategy to apply to all calls made by this service client (i.e. at the client level).
-            This client will not have circuit breakers enabled by default, users can use their own circuit breaker strategy or the convenient :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` provided by the SDK to enable it.
+            This client uses :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` as default if no circuit breaker strategy is provided.
             The specifics of circuit breaker strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/circuit_breakers.html>`__.
 
         :param function circuit_breaker_callback: (optional)
             Callback function to receive any exceptions triggerred by the circuit breaker.
+
+        :param allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this client should allow control characters in the response object. By default, the client will not
+            allow control characters to be in the response object.
         """
         validate_config(config, signer=kwargs.get('signer'))
         if 'signer' in kwargs:
@@ -93,6 +97,10 @@ class NotificationDataPlaneClient(object):
         }
         if 'timeout' in kwargs:
             base_client_init_kwargs['timeout'] = kwargs.get('timeout')
+        if base_client_init_kwargs.get('circuit_breaker_strategy') is None:
+            base_client_init_kwargs['circuit_breaker_strategy'] = circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY
+        if 'allow_control_chars' in kwargs:
+            base_client_init_kwargs['allow_control_chars'] = kwargs.get('allow_control_chars')
         self.base_client = BaseClient("notification_data_plane", config, signer, ons_type_mapping, **base_client_init_kwargs)
         self.retry_strategy = kwargs.get('retry_strategy')
         self.circuit_breaker_callback = kwargs.get('circuit_breaker_callback')
@@ -140,17 +148,24 @@ class NotificationDataPlaneClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type None
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/ons/change_subscription_compartment.py.html>`__ to see an example of how to use change_subscription_compartment API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/ons/change_subscription_compartment.py.html>`__ to see an example of how to use change_subscription_compartment API.
         """
         resource_path = "/subscriptions/{subscriptionId}/actions/changeCompartment"
         method = "POST"
+        operation_name = "change_subscription_compartment"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/notification/20181201/Subscription/ChangeSubscriptionCompartment"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_retry_token",
             "opc_request_id",
@@ -196,14 +211,20 @@ class NotificationDataPlaneClient(object):
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                body=change_subscription_compartment_details)
+                body=change_subscription_compartment_details,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                body=change_subscription_compartment_details)
+                body=change_subscription_compartment_details,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def create_subscription(self, create_subscription_details, **kwargs):
         """
@@ -238,17 +259,24 @@ class NotificationDataPlaneClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ons.models.Subscription`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/ons/create_subscription.py.html>`__ to see an example of how to use create_subscription API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/ons/create_subscription.py.html>`__ to see an example of how to use create_subscription API.
         """
         resource_path = "/subscriptions"
         method = "POST"
+        operation_name = "create_subscription"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/notification/20181201/Subscription/CreateSubscription"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_retry_token",
             "opc_request_id"
@@ -282,14 +310,20 @@ class NotificationDataPlaneClient(object):
                 method=method,
                 header_params=header_params,
                 body=create_subscription_details,
-                response_type="Subscription")
+                response_type="Subscription",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 header_params=header_params,
                 body=create_subscription_details,
-                response_type="Subscription")
+                response_type="Subscription",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def delete_subscription(self, subscription_id, **kwargs):
         """
@@ -320,17 +354,24 @@ class NotificationDataPlaneClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type None
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/ons/delete_subscription.py.html>`__ to see an example of how to use delete_subscription API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/ons/delete_subscription.py.html>`__ to see an example of how to use delete_subscription API.
         """
         resource_path = "/subscriptions/{subscriptionId}"
         method = "DELETE"
+        operation_name = "delete_subscription"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/notification/20181201/Subscription/DeleteSubscription"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_request_id",
             "if_match"
@@ -372,13 +413,19 @@ class NotificationDataPlaneClient(object):
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
-                header_params=header_params)
+                header_params=header_params,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
-                header_params=header_params)
+                header_params=header_params,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def get_confirm_subscription(self, id, token, protocol, **kwargs):
         """
@@ -424,17 +471,24 @@ class NotificationDataPlaneClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ons.models.ConfirmationResult`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/ons/get_confirm_subscription.py.html>`__ to see an example of how to use get_confirm_subscription API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/ons/get_confirm_subscription.py.html>`__ to see an example of how to use get_confirm_subscription API.
         """
         resource_path = "/subscriptions/{id}/confirmation"
         method = "GET"
+        operation_name = "get_confirm_subscription"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/notification/20181201/Subscription/GetConfirmSubscription"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_request_id"
         ]
@@ -482,7 +536,10 @@ class NotificationDataPlaneClient(object):
                 path_params=path_params,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="ConfirmationResult")
+                response_type="ConfirmationResult",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -490,7 +547,10 @@ class NotificationDataPlaneClient(object):
                 path_params=path_params,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="ConfirmationResult")
+                response_type="ConfirmationResult",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def get_subscription(self, subscription_id, **kwargs):
         """
@@ -516,17 +576,24 @@ class NotificationDataPlaneClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ons.models.Subscription`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/ons/get_subscription.py.html>`__ to see an example of how to use get_subscription API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/ons/get_subscription.py.html>`__ to see an example of how to use get_subscription API.
         """
         resource_path = "/subscriptions/{subscriptionId}"
         method = "GET"
+        operation_name = "get_subscription"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/notification/20181201/Subscription/GetSubscription"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_request_id"
         ]
@@ -567,14 +634,20 @@ class NotificationDataPlaneClient(object):
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="Subscription")
+                response_type="Subscription",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="Subscription")
+                response_type="Subscription",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def get_unsubscription(self, id, token, protocol, **kwargs):
         """
@@ -620,17 +693,24 @@ class NotificationDataPlaneClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type str
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/ons/get_unsubscription.py.html>`__ to see an example of how to use get_unsubscription API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/ons/get_unsubscription.py.html>`__ to see an example of how to use get_unsubscription API.
         """
         resource_path = "/subscriptions/{id}/unsubscription"
         method = "GET"
+        operation_name = "get_unsubscription"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/notification/20181201/Subscription/GetUnsubscription"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_request_id"
         ]
@@ -678,7 +758,10 @@ class NotificationDataPlaneClient(object):
                 path_params=path_params,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="str")
+                response_type="str",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -686,7 +769,10 @@ class NotificationDataPlaneClient(object):
                 path_params=path_params,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="str")
+                response_type="str",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def list_subscriptions(self, compartment_id, **kwargs):
         """
@@ -727,17 +813,24 @@ class NotificationDataPlaneClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type list of :class:`~oci.ons.models.SubscriptionSummary`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/ons/list_subscriptions.py.html>`__ to see an example of how to use list_subscriptions API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/ons/list_subscriptions.py.html>`__ to see an example of how to use list_subscriptions API.
         """
         resource_path = "/subscriptions"
         method = "GET"
+        operation_name = "list_subscriptions"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/notification/20181201/Subscription/ListSubscriptions"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "topic_id",
             "page",
@@ -779,14 +872,20 @@ class NotificationDataPlaneClient(object):
                 method=method,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="list[SubscriptionSummary]")
+                response_type="list[SubscriptionSummary]",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="list[SubscriptionSummary]")
+                response_type="list[SubscriptionSummary]",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def publish_message(self, topic_id, message_details, **kwargs):
         """
@@ -843,17 +942,24 @@ class NotificationDataPlaneClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ons.models.PublishResult`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/ons/publish_message.py.html>`__ to see an example of how to use publish_message API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/ons/publish_message.py.html>`__ to see an example of how to use publish_message API.
         """
         resource_path = "/topics/{topicId}/messages"
         method = "POST"
+        operation_name = "publish_message"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/notification/20181201/NotificationTopic/PublishMessage"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_request_id",
             "message_type"
@@ -897,7 +1003,10 @@ class NotificationDataPlaneClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=message_details,
-                response_type="PublishResult")
+                response_type="PublishResult",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -905,7 +1014,10 @@ class NotificationDataPlaneClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=message_details,
-                response_type="PublishResult")
+                response_type="PublishResult",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def resend_subscription_confirmation(self, id, **kwargs):
         """
@@ -931,17 +1043,24 @@ class NotificationDataPlaneClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ons.models.Subscription`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/ons/resend_subscription_confirmation.py.html>`__ to see an example of how to use resend_subscription_confirmation API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/ons/resend_subscription_confirmation.py.html>`__ to see an example of how to use resend_subscription_confirmation API.
         """
         resource_path = "/subscriptions/{id}/resendConfirmation"
         method = "POST"
+        operation_name = "resend_subscription_confirmation"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/notification/20181201/Subscription/ResendSubscriptionConfirmation"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_request_id"
         ]
@@ -982,14 +1101,20 @@ class NotificationDataPlaneClient(object):
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="Subscription")
+                response_type="Subscription",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="Subscription")
+                response_type="Subscription",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def update_subscription(self, subscription_id, update_subscription_details, **kwargs):
         """
@@ -1023,17 +1148,24 @@ class NotificationDataPlaneClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.ons.models.UpdateSubscriptionDetails`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/ons/update_subscription.py.html>`__ to see an example of how to use update_subscription API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/ons/update_subscription.py.html>`__ to see an example of how to use update_subscription API.
         """
         resource_path = "/subscriptions/{subscriptionId}"
         method = "PUT"
+        operation_name = "update_subscription"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/notification/20181201/Subscription/UpdateSubscription"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_request_id",
             "if_match"
@@ -1077,7 +1209,10 @@ class NotificationDataPlaneClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=update_subscription_details,
-                response_type="UpdateSubscriptionDetails")
+                response_type="UpdateSubscriptionDetails",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -1085,4 +1220,7 @@ class NotificationDataPlaneClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=update_subscription_details,
-                response_type="UpdateSubscriptionDetails")
+                response_type="UpdateSubscriptionDetails",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
