@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 from __future__ import absolute_import
@@ -62,11 +62,15 @@ class OperatorControlAssignmentClient(object):
 
         :param obj circuit_breaker_strategy: (optional)
             A circuit breaker strategy to apply to all calls made by this service client (i.e. at the client level).
-            This client will not have circuit breakers enabled by default, users can use their own circuit breaker strategy or the convenient :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` provided by the SDK to enable it.
+            This client uses :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` as default if no circuit breaker strategy is provided.
             The specifics of circuit breaker strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/circuit_breakers.html>`__.
 
         :param function circuit_breaker_callback: (optional)
             Callback function to receive any exceptions triggerred by the circuit breaker.
+
+        :param allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this client should allow control characters in the response object. By default, the client will not
+            allow control characters to be in the response object.
         """
         validate_config(config, signer=kwargs.get('signer'))
         if 'signer' in kwargs:
@@ -95,6 +99,10 @@ class OperatorControlAssignmentClient(object):
         }
         if 'timeout' in kwargs:
             base_client_init_kwargs['timeout'] = kwargs.get('timeout')
+        if base_client_init_kwargs.get('circuit_breaker_strategy') is None:
+            base_client_init_kwargs['circuit_breaker_strategy'] = circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY
+        if 'allow_control_chars' in kwargs:
+            base_client_init_kwargs['allow_control_chars'] = kwargs.get('allow_control_chars')
         self.base_client = BaseClient("operator_control_assignment", config, signer, operator_access_control_type_mapping, **base_client_init_kwargs)
         self.retry_strategy = kwargs.get('retry_strategy')
         self.circuit_breaker_callback = kwargs.get('circuit_breaker_callback')
@@ -135,17 +143,24 @@ class OperatorControlAssignmentClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type None
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/operatoraccesscontrol/change_operator_control_assignment_compartment.py.html>`__ to see an example of how to use change_operator_control_assignment_compartment API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/operatoraccesscontrol/change_operator_control_assignment_compartment.py.html>`__ to see an example of how to use change_operator_control_assignment_compartment API.
         """
         resource_path = "/operatorControlAssignments/{operatorControlAssignmentId}/actions/changeCompartment"
         method = "POST"
+        operation_name = "change_operator_control_assignment_compartment"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/operatoraccesscontrol/20200630/OperatorControlAssignment/ChangeOperatorControlAssignmentCompartment"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_retry_token",
             "if_match",
@@ -191,14 +206,20 @@ class OperatorControlAssignmentClient(object):
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                body=change_operator_control_assignment_compartment_details)
+                body=change_operator_control_assignment_compartment_details,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                body=change_operator_control_assignment_compartment_details)
+                body=change_operator_control_assignment_compartment_details,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def create_operator_control_assignment(self, create_operator_control_assignment_details, **kwargs):
         """
@@ -226,17 +247,24 @@ class OperatorControlAssignmentClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
-        :return: A :class:`~oci.response.Response` object with data of type None
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
+        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.operator_access_control.models.OperatorControlAssignment`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/operatoraccesscontrol/create_operator_control_assignment.py.html>`__ to see an example of how to use create_operator_control_assignment API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/operatoraccesscontrol/create_operator_control_assignment.py.html>`__ to see an example of how to use create_operator_control_assignment API.
         """
         resource_path = "/operatorControlAssignments"
         method = "POST"
+        operation_name = "create_operator_control_assignment"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/operatoraccesscontrol/20200630/OperatorControlAssignment/CreateOperatorControlAssignment"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_retry_token",
             "opc_request_id"
@@ -269,13 +297,21 @@ class OperatorControlAssignmentClient(object):
                 resource_path=resource_path,
                 method=method,
                 header_params=header_params,
-                body=create_operator_control_assignment_details)
+                body=create_operator_control_assignment_details,
+                response_type="OperatorControlAssignment",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 header_params=header_params,
-                body=create_operator_control_assignment_details)
+                body=create_operator_control_assignment_details,
+                response_type="OperatorControlAssignment",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def delete_operator_control_assignment(self, operator_control_assignment_id, **kwargs):
         """
@@ -306,17 +342,24 @@ class OperatorControlAssignmentClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type None
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/operatoraccesscontrol/delete_operator_control_assignment.py.html>`__ to see an example of how to use delete_operator_control_assignment API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/operatoraccesscontrol/delete_operator_control_assignment.py.html>`__ to see an example of how to use delete_operator_control_assignment API.
         """
         resource_path = "/operatorControlAssignments/{operatorControlAssignmentId}"
         method = "DELETE"
+        operation_name = "delete_operator_control_assignment"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/operatoraccesscontrol/20200630/OperatorControlAssignment/DeleteOperatorControlAssignment"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "description",
             "if_match",
@@ -365,14 +408,20 @@ class OperatorControlAssignmentClient(object):
                 method=method,
                 path_params=path_params,
                 query_params=query_params,
-                header_params=header_params)
+                header_params=header_params,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
                 query_params=query_params,
-                header_params=header_params)
+                header_params=header_params,
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def get_operator_control_assignment(self, operator_control_assignment_id, **kwargs):
         """
@@ -393,17 +442,24 @@ class OperatorControlAssignmentClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.operator_access_control.models.OperatorControlAssignment`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/operatoraccesscontrol/get_operator_control_assignment.py.html>`__ to see an example of how to use get_operator_control_assignment API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/operatoraccesscontrol/get_operator_control_assignment.py.html>`__ to see an example of how to use get_operator_control_assignment API.
         """
         resource_path = "/operatorControlAssignments/{operatorControlAssignmentId}"
         method = "GET"
+        operation_name = "get_operator_control_assignment"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/operatoraccesscontrol/20200630/OperatorControlAssignment/GetOperatorControlAssignment"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "opc_request_id"
         ]
@@ -444,14 +500,20 @@ class OperatorControlAssignmentClient(object):
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="OperatorControlAssignment")
+                response_type="OperatorControlAssignment",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 path_params=path_params,
                 header_params=header_params,
-                response_type="OperatorControlAssignment")
+                response_type="OperatorControlAssignment",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def list_operator_control_assignments(self, compartment_id, **kwargs):
         """
@@ -467,10 +529,13 @@ class OperatorControlAssignmentClient(object):
         :param str resource_name: (optional)
             A filter to return only resources that match the given ResourceName.
 
+        :param str resource_type: (optional)
+            A filter to return only lists of resources that match the entire given service type.
+
         :param str lifecycle_state: (optional)
             A filter to return only resources whose lifecycleState matches the given OperatorControlAssignment lifecycleState.
 
-            Allowed values are: "CREATED", "APPLIED", "APPLYFAILED", "DELETED"
+            Allowed values are: "CREATED", "APPLIED", "APPLYFAILED", "UPDATING", "DELETING", "DELETED", "DELETIONFAILED"
 
         :param int limit: (optional)
             The maximum number of items to return.
@@ -499,20 +564,28 @@ class OperatorControlAssignmentClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.operator_access_control.models.OperatorControlAssignmentCollection`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/operatoraccesscontrol/list_operator_control_assignments.py.html>`__ to see an example of how to use list_operator_control_assignments API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/operatoraccesscontrol/list_operator_control_assignments.py.html>`__ to see an example of how to use list_operator_control_assignments API.
         """
         resource_path = "/operatorControlAssignments"
         method = "GET"
+        operation_name = "list_operator_control_assignments"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/operatoraccesscontrol/20200630/OperatorControlAssignment/ListOperatorControlAssignments"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "operator_control_name",
             "resource_name",
+            "resource_type",
             "lifecycle_state",
             "limit",
             "page",
@@ -526,7 +599,7 @@ class OperatorControlAssignmentClient(object):
                 "list_operator_control_assignments got unknown kwargs: {!r}".format(extra_kwargs))
 
         if 'lifecycle_state' in kwargs:
-            lifecycle_state_allowed_values = ["CREATED", "APPLIED", "APPLYFAILED", "DELETED"]
+            lifecycle_state_allowed_values = ["CREATED", "APPLIED", "APPLYFAILED", "UPDATING", "DELETING", "DELETED", "DELETIONFAILED"]
             if kwargs['lifecycle_state'] not in lifecycle_state_allowed_values:
                 raise ValueError(
                     "Invalid value for `lifecycle_state`, must be one of {0}".format(lifecycle_state_allowed_values)
@@ -550,6 +623,7 @@ class OperatorControlAssignmentClient(object):
             "operatorControlName": kwargs.get("operator_control_name", missing),
             "resourceName": kwargs.get("resource_name", missing),
             "compartmentId": compartment_id,
+            "resourceType": kwargs.get("resource_type", missing),
             "lifecycleState": kwargs.get("lifecycle_state", missing),
             "limit": kwargs.get("limit", missing),
             "page": kwargs.get("page", missing),
@@ -580,14 +654,20 @@ class OperatorControlAssignmentClient(object):
                 method=method,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="OperatorControlAssignmentCollection")
+                response_type="OperatorControlAssignmentCollection",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
                 method=method,
                 query_params=query_params,
                 header_params=header_params,
-                response_type="OperatorControlAssignmentCollection")
+                response_type="OperatorControlAssignmentCollection",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
 
     def update_operator_control_assignment(self, operator_control_assignment_id, update_operator_control_assignment_details, **kwargs):
         """
@@ -618,17 +698,24 @@ class OperatorControlAssignmentClient(object):
 
             To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.
 
+        :param bool allow_control_chars: (optional)
+            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
+            By default, the response will not allow control characters in strings
+
         :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.operator_access_control.models.OperatorControlAssignment`
         :rtype: :class:`~oci.response.Response`
 
         :example:
-        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.48.0/operatoraccesscontrol/update_operator_control_assignment.py.html>`__ to see an example of how to use update_operator_control_assignment API.
+        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.74.0/operatoraccesscontrol/update_operator_control_assignment.py.html>`__ to see an example of how to use update_operator_control_assignment API.
         """
         resource_path = "/operatorControlAssignments/{operatorControlAssignmentId}"
         method = "PUT"
+        operation_name = "update_operator_control_assignment"
+        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/operatoraccesscontrol/20200630/OperatorControlAssignment/UpdateOperatorControlAssignment"
 
         # Don't accept unknown kwargs
         expected_kwargs = [
+            "allow_control_chars",
             "retry_strategy",
             "if_match",
             "opc_request_id"
@@ -672,7 +759,10 @@ class OperatorControlAssignmentClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=update_operator_control_assignment_details,
-                response_type="OperatorControlAssignment")
+                response_type="OperatorControlAssignment",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
         else:
             return self.base_client.call_api(
                 resource_path=resource_path,
@@ -680,4 +770,7 @@ class OperatorControlAssignmentClient(object):
                 path_params=path_params,
                 header_params=header_params,
                 body=update_operator_control_assignment_details,
-                response_type="OperatorControlAssignment")
+                response_type="OperatorControlAssignment",
+                allow_control_chars=kwargs.get('allow_control_chars'),
+                operation_name=operation_name,
+                api_reference_link=api_reference_link)
