@@ -1,5 +1,5 @@
 # coding: utf-8
-# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
+# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 # This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 
 
@@ -550,9 +550,14 @@ class Job(object):
     def working_directory(self):
         """
         Gets the working_directory of this Job.
-        File path to the directory from which Terraform runs.
+        File path to the directory to use for running Terraform.
         If not specified, the root directory is used.
-        This parameter is ignored for the `configSourceType` value of `COMPARTMENT_CONFIG_SOURCE`.
+        Required when using a zip Terraform configuration (`configSourceType` value of `ZIP_UPLOAD`) that contains folders.
+        Ignored for the `configSourceType` value of `COMPARTMENT_CONFIG_SOURCE`.
+        For more information about required and recommended file structure, see
+        `File Structure (Terraform Configurations for Resource Manager)`__.
+
+        __ https://docs.cloud.oracle.com/iaas/Content/ResourceManager/Concepts/terraformconfigresourcemanager.htm#filestructure
 
 
         :return: The working_directory of this Job.
@@ -564,9 +569,14 @@ class Job(object):
     def working_directory(self, working_directory):
         """
         Sets the working_directory of this Job.
-        File path to the directory from which Terraform runs.
+        File path to the directory to use for running Terraform.
         If not specified, the root directory is used.
-        This parameter is ignored for the `configSourceType` value of `COMPARTMENT_CONFIG_SOURCE`.
+        Required when using a zip Terraform configuration (`configSourceType` value of `ZIP_UPLOAD`) that contains folders.
+        Ignored for the `configSourceType` value of `COMPARTMENT_CONFIG_SOURCE`.
+        For more information about required and recommended file structure, see
+        `File Structure (Terraform Configurations for Resource Manager)`__.
+
+        __ https://docs.cloud.oracle.com/iaas/Content/ResourceManager/Concepts/terraformconfigresourcemanager.htm#filestructure
 
 
         :param working_directory: The working_directory of this Job.
